==> emodpy_covid-0.0.30-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_qtine_fams.py <==
import json
import copy
import random
from emodpy_covid.mid import schema_to_class as s2c
import sqlite3


coverage = 1.0
q_duration = 14
max_school_id = 52
young_sympto_fraction = 0.2

def get_events( timestep ):
    new_events = []
    hh_ids = []
    with sqlite3.connect('simulation_events.db') as conn:
        cur = conn.cursor()
        query = "SELECT se1.notes from sim_events se1, sim_events se2 where se1.event='NewInfection' and ( se2.event='NewlySymptomatic' or se2.event='NewSevereCase') and se1.individual=se2.individual and se2.SIM_TIME={};".format( timestep ) 
        #print( query )
        cur.execute( query )
        rows = cur.fetchall() 
        for row in rows:
            # extract household id.
            #print( row )
            hh_id = int(row[0].split( "|" )[0].strip("('Household="))
            primary_id = int(row[0].split( "|" )[1].strip("'Primary="))
            print( f"TBD: Isolate everyone in {hh_id} for 2 weeks." )
            # Ideally we want to ignore X% of symptomatics if they are young aka school-age aka primary id <= e.g, 52.
            if primary_id > max_school_id or primary_id <= max_school_id and random.random() < young_sympto_fraction:
                hh_ids.append( hh_id )

    # Get pieces
    event = s2c.get_default_campaign_event() 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    actual_intervention = s2c.get_class_with_defaults( "RouteAwareSimpleVaccine" ) 
    waning = s2c.get_class_with_defaults( "WaningEffectBox" ) 

    # Stitch together
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    intervention.Intervention_List = [ actual_intervention, bcast_intervention ]
    actual_intervention.Waning_Config = waning 

    # Set values
    bcast_intervention.Broadcast_Event = "Quarantine" 
    if coverage != 1.0:
        coordinator.Demographic_Coverage = coverage
    actual_intervention.Vaccine_Type = "Generic"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    waning.Box_Duration = q_duration
    waning.Initial_Effect = 1 # Initial_Effect default is actually -1 for some reason! :(

    event.Start_Day = float(timestep+1) # set from sweep, then by query for number of symptomatics

    for prop_id in hh_ids:
        new_coord = s2c.ReadOnlyDict( copy.deepcopy( json.loads(json.dumps(event.Event_Coordinator_Config))) );
        #new_coord = copy.deepcopy( coordinator )
        prop = []
        prop.append( "Household:" + str( prop_id ) )
        new_coord.Property_Restrictions = prop
        new_event = s2c.get_default_campaign_event() 
        new_event.Event_Coordinator_Config = new_coord
        new_event.Start_Day = float(timestep+1)
        new_events.append( new_event )
    return new_events

def app( timestep ):
    campaign = {}
    campaign["Events"] = []
    events = get_events( timestep )
    #print( "len(events) = {}.".format( len( events ) ) )
    if len(events) == 0:
        return ""
    for event in events:
        campaign["Events"].append( event )

    new_camp_filename = "a_pox_on_all_your_house.json" 
    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file )
    return new_camp_filename

==> emodpy_covid-0.0.53-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_qtine_fams.py <==
import json
import copy
import random
from emodpy_covid.mid import schema_to_class as s2c
import sqlite3


coverage = 1.0
q_duration = 14
max_school_id = 52
young_sympto_fraction = 0.2
debug = False

def get_events( timestep ):
    new_events = []
    hh_ids = []
    with sqlite3.connect('simulation_events.db') as conn:
        cur = conn.cursor()
        query = "SELECT se1.notes from sim_events se1, sim_events se2 where se1.event='NewInfection' and ( se2.event='NewlySymptomatic' or se2.event='NewSevereCase') and se1.individual=se2.individual and se2.SIM_TIME={};".format( timestep ) 
        #print( query )
        cur.execute( query )
        rows = cur.fetchall() 
        for row in rows:
            # extract household id.
            #print( row )
            hh_id = int(row[0].split( "|" )[0].strip("('Household="))
            primary_id = int(row[0].split( "|" )[1].strip("'Primary="))
            print( f"TBD: Quarantine everyone in {hh_id} for 2 weeks." )
            # Ideally we want to ignore X% of symptomatics if they are young aka school-age aka primary id <= e.g, 52.
            if primary_id > max_school_id or primary_id <= max_school_id and random.random() < young_sympto_fraction:
                hh_ids.append( hh_id )

    # Get pieces
    event = s2c.get_default_campaign_event() 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    actual_intervention = s2c.get_class_with_defaults( "RouteAwareSimpleVaccine" ) 
    waning = s2c.get_class_with_defaults( "WaningEffectBox" ) 

    # Stitch together
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    intervention.Intervention_List = [ actual_intervention, bcast_intervention ]
    actual_intervention.Waning_Config = waning 

    # Set values
    bcast_intervention.Broadcast_Event = "Quarantine" 
    if coverage != 1.0:
        coordinator.Demographic_Coverage = coverage
    actual_intervention.Vaccine_Type = "Generic"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    actual_intervention.Intervention_Name = "Quarantine"
    actual_intervention.Duplicate_Policy = "Replace"
    waning.Box_Duration = q_duration
    waning.Initial_Effect = 1 # Initial_Effect default is actually -1 for some reason! :(

    coordinator.finalize()
    intervention.finalize()
    bcast_intervention.finalize()
    actual_intervention.finalize()
    waning.finalize()

    event.Start_Day = float(timestep+1) # set from sweep, then by query for number of symptomatics

    for prop_id in hh_ids:
        new_coord = s2c.ReadOnlyDict( copy.deepcopy( json.loads(json.dumps(event.Event_Coordinator_Config))) );
        #new_coord = copy.deepcopy( coordinator )
        prop = []
        prop.append( "Household:" + str( prop_id ) )
        new_coord.Property_Restrictions = prop
        new_event = s2c.get_default_campaign_event() 
        new_event.Event_Coordinator_Config = new_coord
        new_event.Start_Day = float(timestep+1)
        new_events.append( new_event )
    return new_events

def app( timestep ):
    campaign = {}
    campaign["Events"] = []
    events = get_events( timestep )
    #print( "len(events) = {}.".format( len( events ) ) )
    if len(events) == 0:
        return ""
    for event in events:
        campaign["Events"].append( event )

    new_camp_filename = "a_pox_on_all_your_house"
    if debug:
        new_camp_filename += "_" + str(timestep)
    new_camp_filename += ".json"

    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return new_camp_filename
